==> dokuwiki-2013.05.10.tgz: dokuwiki/inc/lang/hi/lang.php <==
<?php
/**
 * hi language file
 *
 * This file was initially built by fetching translations from other
 * Wiki projects. See the @url lines below. Additional translations
 * and fixes where done for DokuWiki by the people mentioned in the
 * lines starting with @author
 *
 * @url http://svn.wikimedia.org/viewvc/mediawiki/trunk/phase3/languages/messages/MessagesHi.php?view=co
 * @author Abhinav Tyagi <abhinavtyagi11@gmail.com>
 * @author yndesai@gmail.com
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '“';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '‘';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '’';
$lang['btn_edit']              = 'यह पृष्ठ संपादित करें';
$lang['btn_source']            = 'पृष्ठ का श्रोत दिखाएँ';
$lang['btn_show']              = 'पृष्ठ दिखाएँ';
$lang['btn_create']            = 'इस पृष्ठ को बनायें';
$lang['btn_search']            = 'खोजें';
$lang['btn_save']              = 'सुरक्षित करें';
$lang['btn_preview']           = 'पूर्वावलोकन';
$lang['btn_top']               = 'वापस शीर्ष पर';
$lang['btn_newer']             = '<< अधिक विगत';
$lang['btn_older']             = 'अमूल विगत >>';
$lang['btn_revs']              = 'पुराने संशोधन';
$lang['btn_recent']            = 'विगत परिवर्तन';
$lang['btn_upload']            = 'अपलोड करें';
$lang['btn_cancel']            = 'रद्द करें';
$lang['btn_index']             = 'सूचकांक';
$lang['btn_secedit']           = 'संपादित करें';
$lang['btn_login']             = 'लॉग इन';
$lang['btn_logout']            = 'लॉगआउट';
$lang['btn_admin']             = 'व्यवस्थापक';
$lang['btn_update']            = 'अद्यतन करना';
$lang['btn_delete']            = 'मिटाना';
$lang['btn_back']              = 'पीछे';
$lang['btn_backlink']          = 'पिछली कड़ियाँ';
$lang['btn_backtomedia']       = 'मीडिया फाइल चयन पर पीछे जायें';
$lang['btn_subscribe']         = 'सदस्यता प्रबंधन';
$lang['btn_profile']           = 'परिचय संपादित करें';
$lang['user']                  = 'उपयोगकर्ता का नाम';
$lang['pass']                  = 'गुप्त शब्द';
$lang['newpass']               = 'नव गुप्त शब्द';
$lang['passchk']               = 'पासवर्ड दुबारा लिखें';
$lang['remember']              = 'मुझे स्मृत रखना';
$lang['fullname']              = 'सही नाम';
$lang['email']                 = 'ईमेल';
$lang['badlogin']              = 'छमा करें, उपयोगकर्ता का नाम व गुप्त शब्द ग़लत था |';
$lang['minoredit']             = 'अमूल चूल परिवर्तन';
$lang['regmissing']            = 'छमा करें, आपको सारे रिक्त स्थान भरने पड़ेंगे |';
$lang['regbadpass']            = 'दोनो दिए गये गुप्तशब्द समान नहीं हैं | दोबारा प्रयास करें |';
$lang['regpwmail']             = 'आपकी डोकुविकी का गुप्तशब्द';
$lang['reghere']               = 'आपके पास अभी तक कोई खाता नहीं है? बस एक लें |';
$lang['profna']                = 'यह विकी प्रोफ़ाइल संशोधन का समर्थन नहीं करता |';
$lang['profnochange']          = 'कोई परिवर्तन नहीं, कुछ नहीं करना |';
$lang['resendpwdmissing']      = 'छमा करें, आपको सारे रिक्त स्थान भरने पड़ेंगे |';
$lang['resendpwdsuccess']      = 'आपका नवगुप्तशब्द ईमेल द्वारा सम्प्रेषित कर दिया गया है |';
$lang['txt_upload']            = 'अपलोड करने के लिए फ़ाइल चुनें';
$lang['txt_filename']          = 'के रूप में अपलोड करें (वैकल्पिक)';
$lang['txt_overwrt']           = 'अधिलेखित उपस्थित फ़ाइल';
$lang['lockedby']              = 'इस समय तक बंद';
$lang['lockexpire']            = 'बंद समाप्त होगा';
$lang['js']['hidedetails']     = 'विवरण छिपाएँ';
$lang['nothingfound']          = 'कुच्छ नहीं मिला |';
$lang['uploadexist']           = 'फ़ाइल पहले से उपस्थित है. कुछ भी नहीं किया |';
$lang['mediafiles']            = 'उपलब्ध फाइलों में';
$lang['mediaview']             = 'मूल फ़ाइल देखें';
$lang['reference']             = 'संदर्भ के लिए';
$lang['ref_hidden']            = 'कुच्छ संदर्भ उन पन्नो पर हैं जिनको पड़ने की आपको अनुमति नहीं है|';
$lang['toc']                   = 'विषय सूची';
$lang['current']               = 'वर्तमान';
$lang['yours']                 = 'आपका संस्करणः';
$lang['diff']                  = 'वर्तमान संशोधन में मतभेद दिखाइये |';
$lang['diff2']                 = 'चयनित संशोधन के बीच में मतभेद दिखाइये |';
$lang['line']                  = 'रेखा';
$lang['youarehere']            = 'आप यहाँ हैं |';
$lang['lastmod']               = 'अंतिम बार संशोधित';
$lang['by']                    = 'के द्वारा';
$lang['deleted']               = 'हटाया';
$lang['created']               = 'निर्मित';
$lang['external_edit']         = 'बाह्य सम्पादित';
$lang['summary']               = 'सारांश संपादित करें';
$lang['mail_newpage']          = 'पृष्ठ जोड़ा:';
$lang['mail_changed']          = 'पृष्ठ बदला:';
$lang['mail_new_user']         = 'नये उपयोगकर्ता:';
$lang['mail_upload']           = 'अपलोड की गई फ़ाइल:';
$lang['qb_bold']               = 'बोल्ड पाठ्य';
$lang['qb_h1']                 = 'स्तर 1 शीर्षपंक्ति';
$lang['qb_h2']                 = 'स्तर 2 शीर्षपंक्ति';
$lang['qb_h3']                 = 'स्तर 3 शीर्षपंक्ति';
$lang['qb_h4']                 = 'स्तर 4 शीर्षपंक्ति';
$lang['qb_h5']                 = 'स्तर 5 शीर्षपंक्ति';
$lang['qb_link']               = 'आंतरिक कड़ी';
$lang['qb_extlink']            = 'बाह्य कड़ी';
$lang['qb_hr']                 = 'खड़ी रेखा';
$lang['qb_sig']                = 'हस्ताक्षर डालें';
$lang['admin_register']        = 'नया उपयोगकर्ता जोड़ें';
$lang['img_backto']            = 'वापस जाना';
$lang['img_title']             = 'शीर्षक';
$lang['img_caption']           = 'सहशीर्षक';
$lang['img_date']              = 'तिथि';
$lang['img_fsize']             = 'आकार';
$lang['img_artist']            = 'फोटोग्राफर';
$lang['img_format']            = 'प्रारूप';
$lang['img_camera']            = 'कैमरा';
$lang['i_chooselang']          = 'अपनी भाषा चुनें';
$lang['i_installer']           = 'डोकुविकी इंस्टॉलर';
$lang['i_wikiname']            = 'विकी का नाम';
$lang['i_superuser']           = 'महाउपयोगकर्ता';
$lang['i_retry']               = 'पुनःप्रयास';

==> dokuwiki-2024.02.06.tgz: dokuwiki/inc/lang/hi/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author Abhinav Tyagi <abhinavtyagi11@gmail.com>
 * @author yndesai@gmail.com
 * @author Santosh Joshi <sanjujoshhi@gmail.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '“';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '‘';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '’';
$lang['btn_edit']              = 'यह पृष्ठ संपादित करें';
$lang['btn_source']            = 'पृष्ठ का श्रोत दिखाएँ';
$lang['btn_show']              = 'पृष्ठ दिखाएँ';
$lang['btn_create']            = 'इस पृष्ठ को बनायें';
$lang['btn_search']            = 'खोजें';
$lang['btn_save']              = 'सुरक्षित करें';
$lang['btn_preview']           = 'पूर्वावलोकन';
$lang['btn_top']               = 'वापस शीर्ष पर';
$lang['btn_newer']             = '<< अधिक विगत';
$lang['btn_older']             = 'अमूल विगत >>';
$lang['btn_revs']              = 'पुराने संशोधन';
$lang['btn_recent']            = 'विगत परिवर्तन';
$lang['btn_upload']            = 'अपलोड करें';
$lang['btn_cancel']            = 'रद्द करें';
$lang['btn_index']             = 'सूचकांक';
$lang['btn_secedit']           = 'संपादित करें';
$lang['btn_login']             = 'लॉग इन';
$lang['btn_logout']            = 'लॉगआउट';
$lang['btn_admin']             = 'व्यवस्थापक';
$lang['btn_update']            = 'अद्यतन करना';
$lang['btn_delete']            = 'मिटाना';
$lang['btn_back']              = 'पीछे';
$lang['btn_backlink']          = 'पिछली कड़ियाँ';
$lang['btn_subscribe']         = 'सदस्यता प्रबंधन';
$lang['btn_profile']           = 'परिचय संपादित करें';
$lang['btn_resendpwd']         = 'नया पासवर्ड सेट करें';
$lang['btn_draft']             = 'प्रारूप सम्पादित करें';
$lang['btn_draftdel']          = 'प्रारूप मिटायें';
$lang['btn_revert']            = 'वापस लौटाएं';
$lang['btn_apply']             = 'लागू करें';
$lang['btn_deleteuser']        = 'खाता मिटायें';
$lang['user']                  = 'उपयोगकर्ता का नाम';
$lang['pass']                  = 'गुप्त शब्द';
$lang['newpass']               = 'नव गुप्त शब्द';
$lang['passchk']               = 'पासवर्ड दुबारा लिखें';
$lang['remember']              = 'मुझे स्मृत रखना';
$lang['fullname']              = 'सही नाम';
$lang['email']                 = 'ईमेल';
$lang['badlogin']              = 'छमा करें, उपयोगकर्ता का नाम व गुप्त शब्द ग़लत था |';
$lang['minoredit']             = 'अमूल चूल परिवर्तन';
$lang['regmissing']            = 'छमा करें, आपको सारे रिक्त स्थान भरने पड़ेंगे |';
$lang['regbadpass']            = 'दोनो दिए गये गुप्तशब्द समान नहीं हैं | दोबारा प्रयास करें |';
$lang['regpwmail']             = 'आपकी डोकुविकी का गुप्तशब्द';
$lang['reghere']               = 'आपके पास अभी तक कोई खाता नहीं है? बस एक लें |';
$lang['profna']                = 'यह विकी प्रोफ़ाइल संशोधन का समर्थन नहीं करता |';
$lang['profnochange']          = 'कोई परिवर्तन नहीं, कुछ नहीं करना |';
$lang['resendpwdmissing']      = 'छमा करें, आपको सारे रिक्त स्थान भरने पड़ेंगे |';
$lang['resendpwdsuccess']      = 'आपका नवगुप्तशब्द ईमेल द्वारा सम्प्रेषित कर दिया गया है |';
$lang['txt_upload']            = 'अपलोड करने के लिए फ़ाइल चुनें:';
$lang['txt_filename']          = 'के रूप में अपलोड करें (वैकल्पिक):';
$lang['txt_overwrt']           = 'अधिलेखित उपस्थित फ़ाइल';
$lang['lockedby']              = 'इस समय तक बंद:';
$lang['lockexpire']            = 'बंद समाप्त होगा:';
$lang['js']['hidedetails']     = 'विवरण छिपाएँ';
$lang['nothingfound']          = 'कुच्छ नहीं मिला |';
$lang['uploadexist']           = 'फ़ाइल पहले से उपस्थित है. कुछ भी नहीं किया |';
$lang['mediafiles']            = 'उपलब्ध फाइलों में';
$lang['mediaview']             = 'मूल फ़ाइल देखें';
$lang['reference']             = 'संदर्भ के लिए';
$lang['ref_hidden']            = 'कुच्छ संदर्भ उन पन्नो पर हैं जिनको पड़ने की आपको अनुमति नहीं है|';
$lang['toc']                   = 'विषय सूची';
$lang['current']               = 'वर्तमान';
$lang['yours']                 = 'आपका संस्करणः';
$lang['diff']                  = 'वर्तमान संशोधन में मतभेद दिखाइये |';
$lang['diff2']                 = 'चयनित संशोधन के बीच में मतभेद दिखाइये |';
$lang['line']                  = 'रेखा';
$lang['youarehere']            = 'आप यहाँ हैं |:';
$lang['lastmod']               = 'अंतिम बार संशोधित:';
$lang['by']                    = 'के द्वारा';
$lang['deleted']               = 'हटाया';
$lang['created']               = 'निर्मित';
$lang['external_edit']         = 'बाह्य सम्पादित';
$lang['summary']               = 'सारांश संपादित करें';
$lang['mail_newpage']          = 'पृष्ठ जोड़ा:';
$lang['mail_changed']          = 'पृष्ठ बदला:';
$lang['mail_new_user']         = 'नये उपयोगकर्ता:';
$lang['mail_upload']           = 'अपलोड की गई फ़ाइल:';
$lang['qb_bold']               = 'बोल्ड पाठ्य';
$lang['qb_h1']                 = 'स्तर 1 शीर्षपंक्ति';
$lang['qb_h2']                 = 'स्तर 2 शीर्षपंक्ति';
$lang['qb_h3']                 = 'स्तर 3 शीर्षपंक्ति';
$lang['qb_h4']                 = 'स्तर 4 शीर्षपंक्ति';
$lang['qb_h5']                 = 'स्तर 5 शीर्षपंक्ति';
$lang['qb_link']               = 'आंतरिक कड़ी';
$lang['qb_extlink']            = 'बाह्य कड़ी';
$lang['qb_hr']                 = 'खड़ी रेखा';
$lang['qb_sig']                = 'हस्ताक्षर डालें';
$lang['btn_img_backto']            = 'वापस जाना %s';
$lang['img_title']             = 'शीर्षक:';
$lang['img_caption']           = 'सहशीर्षक:';
$lang['img_date']              = 'तिथि:';
$lang['img_fsize']             = 'आकार:';
$lang['img_artist']            = 'फोटोग्राफर:';
$lang['img_format']            = 'प्रारूप:';
$lang['img_camera']            = 'कैमरा:';
$lang['i_chooselang']          = 'अपनी भाषा चुनें';
$lang['i_installer']           = 'डोकुविकी इंस्टॉलर';
$lang['i_wikiname']            = 'विकी का नाम';
$lang['i_superuser']           = 'महाउपयोगकर्ता';
$lang['i_retry']               = 'पुनःप्रयास';
